// complete.cs - 
//--------------------------------------------------------------
using System;

[AttributeUsage(AttributeTargets.All)]
public class CodeStatusAttribute : System.Attribute
{
   private string STATUS;
   private string TESTER;
   private string CODER;

   public CodeStatusAttribute( string Status )
   {
      this.STATUS = Status;
   }

   public string Tester
   {
      set 
      {
         TESTER = value;
      }
      get
      {
          return TESTER;
      }
   }

   public string Coder
   {
      set 
      {
         CODER = value;
      }
      get
      {
         return CODER;
      }
   }
   
   public override string ToString()
   {
      return STATUS;
   }
}

// attrUsed.cs - using the CodeStatus attribute 
//-----------------------------------------------

[CodeStatus("Beta", Coder="Brad")]
public class Circle
{
    public Circle()
    {
        // Set up and build a circle class
    }
}

[CodeStatus("Final", Coder="Fred", Tester="John")]
public class Square
{
    public Square()
    {
        // Set up and build a square class
    }
}

[CodeStatus("Alpha")]
public class Triangle
{
    public Triangle()
    {
        // Set up and build a triangle class
    }
}

[CodeStatus("Final", Coder="Bill")]
public class Rectangle
{
    public Rectangle()
    {
        // Set up and build a rectangle class
    }
}

class myApp
{
   public static void Main()
   {
      PrintAttributes(typeof(Circle));
      PrintAttributes(typeof(Triangle));
      PrintAttributes(typeof(Square));
      PrintAttributes(typeof(Rectangle));
   }

   public static void PrintAttributes( Type psdType )
   {
      Console.WriteLine("\nAttributes for: {0}", psdType.ToString());

      Attribute[] attribs = Attribute.GetCustomAttributes(psdType);
      foreach (Attribute attr in attribs)
      {
          CodeStatusAttribute item = (CodeStatusAttribute) attr;
          Console.WriteLine(
              "Status is {0}. Coder is {1}. Tester is {2}.",
              item.ToString(), item.Coder, item.Tester);
      }
   }
}
